# coding: utf-8

# flake8: noqa
"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    The version of the OpenAPI document: 2024-10-15
    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from openapi_client import lazy_imports

# import models into model package
if not lazy_imports:
    from openapi_client.models.api_job_error_payload import APIJobErrorPayload
    from openapi_client.models.account_enum import AccountEnum
    from openapi_client.models.account_response_object_resource import AccountResponseObjectResource
    from openapi_client.models.account_response_object_resource_attributes import AccountResponseObjectResourceAttributes
    from openapi_client.models.attribution_enum import AttributionEnum
    from openapi_client.models.audiences_sub_object import AudiencesSubObject
    from openapi_client.models.back_in_stock_subscription_enum import BackInStockSubscriptionEnum
    from openapi_client.models.base_event_create_query_resource_object import BaseEventCreateQueryResourceObject
    from openapi_client.models.base_event_create_query_resource_object_attributes import BaseEventCreateQueryResourceObjectAttributes
    from openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource import BulkProfileSuppressionsCreateJobResponseObjectResource
    from openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource_attributes import BulkProfileSuppressionsCreateJobResponseObjectResourceAttributes
    from openapi_client.models.bulk_profile_suppressions_remove_job_response_object_resource import BulkProfileSuppressionsRemoveJobResponseObjectResource
    from openapi_client.models.campaign_clone_query import CampaignCloneQuery
    from openapi_client.models.campaign_clone_query_resource_object import CampaignCloneQueryResourceObject
    from openapi_client.models.campaign_clone_query_resource_object_attributes import CampaignCloneQueryResourceObjectAttributes
    from openapi_client.models.campaign_create_query import CampaignCreateQuery
    from openapi_client.models.campaign_create_query_resource_object import CampaignCreateQueryResourceObject
    from openapi_client.models.campaign_create_query_resource_object_attributes import CampaignCreateQueryResourceObjectAttributes
    from openapi_client.models.campaign_create_query_resource_object_attributes_campaign_messages import CampaignCreateQueryResourceObjectAttributesCampaignMessages
    from openapi_client.models.campaign_enum import CampaignEnum
    from openapi_client.models.campaign_message_assign_template_query import CampaignMessageAssignTemplateQuery
    from openapi_client.models.campaign_message_assign_template_query_resource_object import CampaignMessageAssignTemplateQueryResourceObject
    from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships import CampaignMessageAssignTemplateQueryResourceObjectRelationships
    from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplate
    from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template_data import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplateData
    from openapi_client.models.campaign_message_create_query_resource_object import CampaignMessageCreateQueryResourceObject
    from openapi_client.models.campaign_message_create_query_resource_object_attributes import CampaignMessageCreateQueryResourceObjectAttributes
    from openapi_client.models.campaign_message_enum import CampaignMessageEnum
    from openapi_client.models.campaign_message_partial_update_query import CampaignMessagePartialUpdateQuery
    from openapi_client.models.campaign_message_partial_update_query_resource_object import CampaignMessagePartialUpdateQueryResourceObject
    from openapi_client.models.campaign_message_partial_update_query_resource_object_attributes import CampaignMessagePartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.campaign_message_response_object_resource import CampaignMessageResponseObjectResource
    from openapi_client.models.campaign_message_response_object_resource_attributes import CampaignMessageResponseObjectResourceAttributes
    from openapi_client.models.campaign_partial_update_query import CampaignPartialUpdateQuery
    from openapi_client.models.campaign_partial_update_query_resource_object import CampaignPartialUpdateQueryResourceObject
    from openapi_client.models.campaign_partial_update_query_resource_object_attributes import CampaignPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.campaign_recipient_estimation_enum import CampaignRecipientEstimationEnum
    from openapi_client.models.campaign_recipient_estimation_job_create_query import CampaignRecipientEstimationJobCreateQuery
    from openapi_client.models.campaign_recipient_estimation_job_create_query_resource_object import CampaignRecipientEstimationJobCreateQueryResourceObject
    from openapi_client.models.campaign_recipient_estimation_job_enum import CampaignRecipientEstimationJobEnum
    from openapi_client.models.campaign_recipient_estimation_job_response_object_resource import CampaignRecipientEstimationJobResponseObjectResource
    from openapi_client.models.campaign_recipient_estimation_job_response_object_resource_attributes import CampaignRecipientEstimationJobResponseObjectResourceAttributes
    from openapi_client.models.campaign_recipient_estimation_response_object_resource import CampaignRecipientEstimationResponseObjectResource
    from openapi_client.models.campaign_recipient_estimation_response_object_resource_attributes import CampaignRecipientEstimationResponseObjectResourceAttributes
    from openapi_client.models.campaign_response_object_resource import CampaignResponseObjectResource
    from openapi_client.models.campaign_response_object_resource_attributes import CampaignResponseObjectResourceAttributes
    from openapi_client.models.campaign_send_job_create_query import CampaignSendJobCreateQuery
    from openapi_client.models.campaign_send_job_create_query_resource_object import CampaignSendJobCreateQueryResourceObject
    from openapi_client.models.campaign_send_job_enum import CampaignSendJobEnum
    from openapi_client.models.campaign_send_job_partial_update_query import CampaignSendJobPartialUpdateQuery
    from openapi_client.models.campaign_send_job_partial_update_query_resource_object import CampaignSendJobPartialUpdateQueryResourceObject
    from openapi_client.models.campaign_send_job_partial_update_query_resource_object_attributes import CampaignSendJobPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.campaign_send_job_response_object_resource import CampaignSendJobResponseObjectResource
    from openapi_client.models.campaign_send_job_response_object_resource_attributes import CampaignSendJobResponseObjectResourceAttributes
    from openapi_client.models.campaign_values_report_enum import CampaignValuesReportEnum
    from openapi_client.models.campaign_values_request_dto import CampaignValuesRequestDTO
    from openapi_client.models.campaign_values_request_dto_resource_object import CampaignValuesRequestDTOResourceObject
    from openapi_client.models.campaign_values_request_dto_resource_object_attributes import CampaignValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.catalog_category_bulk_create_job_enum import CatalogCategoryBulkCreateJobEnum
    from openapi_client.models.catalog_category_bulk_delete_job_enum import CatalogCategoryBulkDeleteJobEnum
    from openapi_client.models.catalog_category_bulk_update_job_enum import CatalogCategoryBulkUpdateJobEnum
    from openapi_client.models.catalog_category_create_job_create_query import CatalogCategoryCreateJobCreateQuery
    from openapi_client.models.catalog_category_create_job_create_query_resource_object import CatalogCategoryCreateJobCreateQueryResourceObject
    from openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes import CatalogCategoryCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes_categories import CatalogCategoryCreateJobCreateQueryResourceObjectAttributesCategories
    from openapi_client.models.catalog_category_create_job_response_object_resource import CatalogCategoryCreateJobResponseObjectResource
    from openapi_client.models.catalog_category_create_query import CatalogCategoryCreateQuery
    from openapi_client.models.catalog_category_create_query_resource_object import CatalogCategoryCreateQueryResourceObject
    from openapi_client.models.catalog_category_create_query_resource_object_attributes import CatalogCategoryCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_create_query_resource_object_relationships import CatalogCategoryCreateQueryResourceObjectRelationships
    from openapi_client.models.catalog_category_create_query_resource_object_relationships_items import CatalogCategoryCreateQueryResourceObjectRelationshipsItems
    from openapi_client.models.catalog_category_delete_job_create_query import CatalogCategoryDeleteJobCreateQuery
    from openapi_client.models.catalog_category_delete_job_create_query_resource_object import CatalogCategoryDeleteJobCreateQueryResourceObject
    from openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes_categories import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributesCategories
    from openapi_client.models.catalog_category_delete_job_response_object_resource import CatalogCategoryDeleteJobResponseObjectResource
    from openapi_client.models.catalog_category_delete_query_resource_object import CatalogCategoryDeleteQueryResourceObject
    from openapi_client.models.catalog_category_enum import CatalogCategoryEnum
    from openapi_client.models.catalog_category_item_op import CatalogCategoryItemOp
    from openapi_client.models.catalog_category_response_object_resource import CatalogCategoryResponseObjectResource
    from openapi_client.models.catalog_category_response_object_resource_attributes import CatalogCategoryResponseObjectResourceAttributes
    from openapi_client.models.catalog_category_update_job_create_query import CatalogCategoryUpdateJobCreateQuery
    from openapi_client.models.catalog_category_update_job_create_query_resource_object import CatalogCategoryUpdateJobCreateQueryResourceObject
    from openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes_categories import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributesCategories
    from openapi_client.models.catalog_category_update_job_response_object_resource import CatalogCategoryUpdateJobResponseObjectResource
    from openapi_client.models.catalog_category_update_query import CatalogCategoryUpdateQuery
    from openapi_client.models.catalog_category_update_query_resource_object import CatalogCategoryUpdateQueryResourceObject
    from openapi_client.models.catalog_category_update_query_resource_object_attributes import CatalogCategoryUpdateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_bulk_create_job_enum import CatalogItemBulkCreateJobEnum
    from openapi_client.models.catalog_item_bulk_delete_job_enum import CatalogItemBulkDeleteJobEnum
    from openapi_client.models.catalog_item_bulk_update_job_enum import CatalogItemBulkUpdateJobEnum
    from openapi_client.models.catalog_item_category_op import CatalogItemCategoryOp
    from openapi_client.models.catalog_item_create_job_create_query import CatalogItemCreateJobCreateQuery
    from openapi_client.models.catalog_item_create_job_create_query_resource_object import CatalogItemCreateJobCreateQueryResourceObject
    from openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes import CatalogItemCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes_items import CatalogItemCreateJobCreateQueryResourceObjectAttributesItems
    from openapi_client.models.catalog_item_create_job_response_object_resource import CatalogItemCreateJobResponseObjectResource
    from openapi_client.models.catalog_item_create_query import CatalogItemCreateQuery
    from openapi_client.models.catalog_item_create_query_resource_object import CatalogItemCreateQueryResourceObject
    from openapi_client.models.catalog_item_create_query_resource_object_attributes import CatalogItemCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_create_query_resource_object_relationships import CatalogItemCreateQueryResourceObjectRelationships
    from openapi_client.models.catalog_item_create_query_resource_object_relationships_categories import CatalogItemCreateQueryResourceObjectRelationshipsCategories
    from openapi_client.models.catalog_item_delete_job_create_query import CatalogItemDeleteJobCreateQuery
    from openapi_client.models.catalog_item_delete_job_create_query_resource_object import CatalogItemDeleteJobCreateQueryResourceObject
    from openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes import CatalogItemDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes_items import CatalogItemDeleteJobCreateQueryResourceObjectAttributesItems
    from openapi_client.models.catalog_item_delete_job_response_object_resource import CatalogItemDeleteJobResponseObjectResource
    from openapi_client.models.catalog_item_delete_query_resource_object import CatalogItemDeleteQueryResourceObject
    from openapi_client.models.catalog_item_enum import CatalogItemEnum
    from openapi_client.models.catalog_item_response_object_resource import CatalogItemResponseObjectResource
    from openapi_client.models.catalog_item_response_object_resource_attributes import CatalogItemResponseObjectResourceAttributes
    from openapi_client.models.catalog_item_update_job_create_query import CatalogItemUpdateJobCreateQuery
    from openapi_client.models.catalog_item_update_job_create_query_resource_object import CatalogItemUpdateJobCreateQueryResourceObject
    from openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes import CatalogItemUpdateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes_items import CatalogItemUpdateJobCreateQueryResourceObjectAttributesItems
    from openapi_client.models.catalog_item_update_job_response_object_resource import CatalogItemUpdateJobResponseObjectResource
    from openapi_client.models.catalog_item_update_query import CatalogItemUpdateQuery
    from openapi_client.models.catalog_item_update_query_resource_object import CatalogItemUpdateQueryResourceObject
    from openapi_client.models.catalog_item_update_query_resource_object_attributes import CatalogItemUpdateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_bulk_create_job_enum import CatalogVariantBulkCreateJobEnum
    from openapi_client.models.catalog_variant_bulk_delete_job_enum import CatalogVariantBulkDeleteJobEnum
    from openapi_client.models.catalog_variant_bulk_update_job_enum import CatalogVariantBulkUpdateJobEnum
    from openapi_client.models.catalog_variant_create_job_create_query import CatalogVariantCreateJobCreateQuery
    from openapi_client.models.catalog_variant_create_job_create_query_resource_object import CatalogVariantCreateJobCreateQueryResourceObject
    from openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes import CatalogVariantCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes_variants import CatalogVariantCreateJobCreateQueryResourceObjectAttributesVariants
    from openapi_client.models.catalog_variant_create_job_response_object_resource import CatalogVariantCreateJobResponseObjectResource
    from openapi_client.models.catalog_variant_create_query import CatalogVariantCreateQuery
    from openapi_client.models.catalog_variant_create_query_resource_object import CatalogVariantCreateQueryResourceObject
    from openapi_client.models.catalog_variant_create_query_resource_object_attributes import CatalogVariantCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_create_query_resource_object_relationships import CatalogVariantCreateQueryResourceObjectRelationships
    from openapi_client.models.catalog_variant_create_query_resource_object_relationships_item import CatalogVariantCreateQueryResourceObjectRelationshipsItem
    from openapi_client.models.catalog_variant_create_query_resource_object_relationships_item_data import CatalogVariantCreateQueryResourceObjectRelationshipsItemData
    from openapi_client.models.catalog_variant_delete_job_create_query import CatalogVariantDeleteJobCreateQuery
    from openapi_client.models.catalog_variant_delete_job_create_query_resource_object import CatalogVariantDeleteJobCreateQueryResourceObject
    from openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes import CatalogVariantDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes_variants import CatalogVariantDeleteJobCreateQueryResourceObjectAttributesVariants
    from openapi_client.models.catalog_variant_delete_job_response_object_resource import CatalogVariantDeleteJobResponseObjectResource
    from openapi_client.models.catalog_variant_delete_query_resource_object import CatalogVariantDeleteQueryResourceObject
    from openapi_client.models.catalog_variant_enum import CatalogVariantEnum
    from openapi_client.models.catalog_variant_response_object_resource import CatalogVariantResponseObjectResource
    from openapi_client.models.catalog_variant_response_object_resource_attributes import CatalogVariantResponseObjectResourceAttributes
    from openapi_client.models.catalog_variant_update_job_create_query import CatalogVariantUpdateJobCreateQuery
    from openapi_client.models.catalog_variant_update_job_create_query_resource_object import CatalogVariantUpdateJobCreateQueryResourceObject
    from openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes import CatalogVariantUpdateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes_variants import CatalogVariantUpdateJobCreateQueryResourceObjectAttributesVariants
    from openapi_client.models.catalog_variant_update_job_response_object_resource import CatalogVariantUpdateJobResponseObjectResource
    from openapi_client.models.catalog_variant_update_query import CatalogVariantUpdateQuery
    from openapi_client.models.catalog_variant_update_query_resource_object import CatalogVariantUpdateQueryResourceObject
    from openapi_client.models.catalog_variant_update_query_resource_object_attributes import CatalogVariantUpdateQueryResourceObjectAttributes
    from openapi_client.models.collection_links import CollectionLinks
    from openapi_client.models.condition_group import ConditionGroup
    from openapi_client.models.contact_information import ContactInformation
    from openapi_client.models.coupon_code_bulk_create_job_enum import CouponCodeBulkCreateJobEnum
    from openapi_client.models.coupon_code_create_job_create_query import CouponCodeCreateJobCreateQuery
    from openapi_client.models.coupon_code_create_job_create_query_resource_object import CouponCodeCreateJobCreateQueryResourceObject
    from openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes import CouponCodeCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes_coupon_codes import CouponCodeCreateJobCreateQueryResourceObjectAttributesCouponCodes
    from openapi_client.models.coupon_code_create_job_response_object_resource import CouponCodeCreateJobResponseObjectResource
    from openapi_client.models.coupon_code_create_job_response_object_resource_attributes import CouponCodeCreateJobResponseObjectResourceAttributes
    from openapi_client.models.coupon_code_create_query import CouponCodeCreateQuery
    from openapi_client.models.coupon_code_create_query_resource_object import CouponCodeCreateQueryResourceObject
    from openapi_client.models.coupon_code_create_query_resource_object_attributes import CouponCodeCreateQueryResourceObjectAttributes
    from openapi_client.models.coupon_code_create_query_resource_object_relationships import CouponCodeCreateQueryResourceObjectRelationships
    from openapi_client.models.coupon_code_create_query_resource_object_relationships_coupon import CouponCodeCreateQueryResourceObjectRelationshipsCoupon
    from openapi_client.models.coupon_code_enum import CouponCodeEnum
    from openapi_client.models.coupon_code_response_object_resource import CouponCodeResponseObjectResource
    from openapi_client.models.coupon_code_response_object_resource_attributes import CouponCodeResponseObjectResourceAttributes
    from openapi_client.models.coupon_code_update_query import CouponCodeUpdateQuery
    from openapi_client.models.coupon_code_update_query_resource_object import CouponCodeUpdateQueryResourceObject
    from openapi_client.models.coupon_code_update_query_resource_object_attributes import CouponCodeUpdateQueryResourceObjectAttributes
    from openapi_client.models.coupon_create_query import CouponCreateQuery
    from openapi_client.models.coupon_create_query_resource_object import CouponCreateQueryResourceObject
    from openapi_client.models.coupon_enum import CouponEnum
    from openapi_client.models.coupon_response_object_resource import CouponResponseObjectResource
    from openapi_client.models.coupon_response_object_resource_attributes import CouponResponseObjectResourceAttributes
    from openapi_client.models.coupon_update_query import CouponUpdateQuery
    from openapi_client.models.coupon_update_query_resource_object import CouponUpdateQueryResourceObject
    from openapi_client.models.coupon_update_query_resource_object_attributes import CouponUpdateQueryResourceObjectAttributes
    from openapi_client.models.custom_tracking_param_dto import CustomTrackingParamDTO
    from openapi_client.models.data_privacy_create_deletion_job_query import DataPrivacyCreateDeletionJobQuery
    from openapi_client.models.data_privacy_create_deletion_job_query_resource_object import DataPrivacyCreateDeletionJobQueryResourceObject
    from openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes import DataPrivacyCreateDeletionJobQueryResourceObjectAttributes
    from openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes_profile import DataPrivacyCreateDeletionJobQueryResourceObjectAttributesProfile
    from openapi_client.models.data_privacy_deletion_job_enum import DataPrivacyDeletionJobEnum
    from openapi_client.models.data_privacy_profile_query_resource_object import DataPrivacyProfileQueryResourceObject
    from openapi_client.models.data_privacy_profile_query_resource_object_attributes import DataPrivacyProfileQueryResourceObjectAttributes
    from openapi_client.models.delete_tag_group_response import DeleteTagGroupResponse
    from openapi_client.models.device_metadata import DeviceMetadata
    from openapi_client.models.email_channel import EmailChannel
    from openapi_client.models.email_marketing import EmailMarketing
    from openapi_client.models.email_marketing_list_suppression import EmailMarketingListSuppression
    from openapi_client.models.email_marketing_suppression import EmailMarketingSuppression
    from openapi_client.models.email_subscription_parameters import EmailSubscriptionParameters
    from openapi_client.models.error_source import ErrorSource
    from openapi_client.models.event_bulk_create_enum import EventBulkCreateEnum
    from openapi_client.models.event_bulk_create_job_enum import EventBulkCreateJobEnum
    from openapi_client.models.event_create_query_v2 import EventCreateQueryV2
    from openapi_client.models.event_create_query_v2_resource_object import EventCreateQueryV2ResourceObject
    from openapi_client.models.event_create_query_v2_resource_object_attributes import EventCreateQueryV2ResourceObjectAttributes
    from openapi_client.models.event_create_query_v2_resource_object_attributes_metric import EventCreateQueryV2ResourceObjectAttributesMetric
    from openapi_client.models.event_create_query_v2_resource_object_attributes_profile import EventCreateQueryV2ResourceObjectAttributesProfile
    from openapi_client.models.event_enum import EventEnum
    from openapi_client.models.event_profile_create_query_resource_object import EventProfileCreateQueryResourceObject
    from openapi_client.models.event_profile_create_query_resource_object_attributes import EventProfileCreateQueryResourceObjectAttributes
    from openapi_client.models.event_response_object_resource import EventResponseObjectResource
    from openapi_client.models.event_response_object_resource_attributes import EventResponseObjectResourceAttributes
    from openapi_client.models.events_bulk_create_job import EventsBulkCreateJob
    from openapi_client.models.events_bulk_create_job_resource_object import EventsBulkCreateJobResourceObject
    from openapi_client.models.events_bulk_create_job_resource_object_attributes import EventsBulkCreateJobResourceObjectAttributes
    from openapi_client.models.events_bulk_create_job_resource_object_attributes_events_bulk_create import EventsBulkCreateJobResourceObjectAttributesEventsBulkCreate
    from openapi_client.models.events_bulk_create_query_resource_object import EventsBulkCreateQueryResourceObject
    from openapi_client.models.events_bulk_create_query_resource_object_attributes import EventsBulkCreateQueryResourceObjectAttributes
    from openapi_client.models.events_bulk_create_query_resource_object_attributes_events import EventsBulkCreateQueryResourceObjectAttributesEvents
    from openapi_client.models.events_bulk_create_query_resource_object_attributes_profile import EventsBulkCreateQueryResourceObjectAttributesProfile
    from openapi_client.models.flow_action_enum import FlowActionEnum
    from openapi_client.models.flow_action_response_object_resource import FlowActionResponseObjectResource
    from openapi_client.models.flow_action_response_object_resource_attributes import FlowActionResponseObjectResourceAttributes
    from openapi_client.models.flow_enum import FlowEnum
    from openapi_client.models.flow_message_enum import FlowMessageEnum
    from openapi_client.models.flow_message_response_object_resource import FlowMessageResponseObjectResource
    from openapi_client.models.flow_message_response_object_resource_attributes import FlowMessageResponseObjectResourceAttributes
    from openapi_client.models.flow_response_object_resource import FlowResponseObjectResource
    from openapi_client.models.flow_response_object_resource_attributes import FlowResponseObjectResourceAttributes
    from openapi_client.models.flow_series_report_enum import FlowSeriesReportEnum
    from openapi_client.models.flow_series_request_dto import FlowSeriesRequestDTO
    from openapi_client.models.flow_series_request_dto_resource_object import FlowSeriesRequestDTOResourceObject
    from openapi_client.models.flow_series_request_dto_resource_object_attributes import FlowSeriesRequestDTOResourceObjectAttributes
    from openapi_client.models.flow_update_query import FlowUpdateQuery
    from openapi_client.models.flow_update_query_resource_object import FlowUpdateQueryResourceObject
    from openapi_client.models.flow_update_query_resource_object_attributes import FlowUpdateQueryResourceObjectAttributes
    from openapi_client.models.flow_values_report_enum import FlowValuesReportEnum
    from openapi_client.models.flow_values_request_dto import FlowValuesRequestDTO
    from openapi_client.models.flow_values_request_dto_resource_object import FlowValuesRequestDTOResourceObject
    from openapi_client.models.flow_values_request_dto_resource_object_attributes import FlowValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.form_enum import FormEnum
    from openapi_client.models.form_response_object_resource import FormResponseObjectResource
    from openapi_client.models.form_response_object_resource_attributes import FormResponseObjectResourceAttributes
    from openapi_client.models.form_series_report_enum import FormSeriesReportEnum
    from openapi_client.models.form_series_request_dto import FormSeriesRequestDTO
    from openapi_client.models.form_series_request_dto_resource_object import FormSeriesRequestDTOResourceObject
    from openapi_client.models.form_series_request_dto_resource_object_attributes import FormSeriesRequestDTOResourceObjectAttributes
    from openapi_client.models.form_values_report_enum import FormValuesReportEnum
    from openapi_client.models.form_values_request_dto import FormValuesRequestDTO
    from openapi_client.models.form_values_request_dto_resource_object import FormValuesRequestDTOResourceObject
    from openapi_client.models.form_values_request_dto_resource_object_attributes import FormValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.form_version_ab_test import FormVersionABTest
    from openapi_client.models.form_version_enum import FormVersionEnum
    from openapi_client.models.form_version_response_object_resource import FormVersionResponseObjectResource
    from openapi_client.models.form_version_response_object_resource_attributes import FormVersionResponseObjectResourceAttributes
    from openapi_client.models.get_account_response import GetAccountResponse
    from openapi_client.models.get_account_response_collection import GetAccountResponseCollection
    from openapi_client.models.get_accounts4_xx_response import GetAccounts4XXResponse
    from openapi_client.models.get_accounts4_xx_response_errors_inner import GetAccounts4XXResponseErrorsInner
    from openapi_client.models.get_accounts4_xx_response_errors_inner_source import GetAccounts4XXResponseErrorsInnerSource
    from openapi_client.models.get_bulk_profile_suppressions_create_job_response import GetBulkProfileSuppressionsCreateJobResponse
    from openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection import GetBulkProfileSuppressionsCreateJobResponseCollection
    from openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection_data_inner import GetBulkProfileSuppressionsCreateJobResponseCollectionDataInner
    from openapi_client.models.get_bulk_profile_suppressions_remove_job_response import GetBulkProfileSuppressionsRemoveJobResponse
    from openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection import GetBulkProfileSuppressionsRemoveJobResponseCollection
    from openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection_data_inner import GetBulkProfileSuppressionsRemoveJobResponseCollectionDataInner
    from openapi_client.models.get_campaign_message_campaign_relationship_response import GetCampaignMessageCampaignRelationshipResponse
    from openapi_client.models.get_campaign_message_campaign_relationship_response_data import GetCampaignMessageCampaignRelationshipResponseData
    from openapi_client.models.get_campaign_message_response_collection_compound_document import GetCampaignMessageResponseCollectionCompoundDocument
    from openapi_client.models.get_campaign_message_response_compound_document import GetCampaignMessageResponseCompoundDocument
    from openapi_client.models.get_campaign_message_response_compound_document_data import GetCampaignMessageResponseCompoundDocumentData
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaign
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign_data import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaignData
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template_data import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData
    from openapi_client.models.get_campaign_message_template_relationship_response import GetCampaignMessageTemplateRelationshipResponse
    from openapi_client.models.get_campaign_messages_relationship_list_response_collection import GetCampaignMessagesRelationshipListResponseCollection
    from openapi_client.models.get_campaign_messages_relationship_list_response_collection_data_inner import GetCampaignMessagesRelationshipListResponseCollectionDataInner
    from openapi_client.models.get_campaign_recipient_estimation_job_response import GetCampaignRecipientEstimationJobResponse
    from openapi_client.models.get_campaign_recipient_estimation_response import GetCampaignRecipientEstimationResponse
    from openapi_client.models.get_campaign_response import GetCampaignResponse
    from openapi_client.models.get_campaign_response_collection_compound_document import GetCampaignResponseCollectionCompoundDocument
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner import GetCampaignResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessages
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages_data_inner import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessagesDataInner
    from openapi_client.models.get_campaign_response_compound_document import GetCampaignResponseCompoundDocument
    from openapi_client.models.get_campaign_response_data import GetCampaignResponseData
    from openapi_client.models.get_campaign_response_data_all_of_relationships import GetCampaignResponseDataAllOfRelationships
    from openapi_client.models.get_campaign_send_job_response import GetCampaignSendJobResponse
    from openapi_client.models.get_campaign_tag_relationship_list_response_collection import GetCampaignTagRelationshipListResponseCollection
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document import GetCatalogCategoryCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner
    from openapi_client.models.get_catalog_category_create_job_response_compound_document import GetCatalogCategoryCreateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_category_delete_job_response import GetCatalogCategoryDeleteJobResponse
    from openapi_client.models.get_catalog_category_delete_job_response_collection import GetCatalogCategoryDeleteJobResponseCollection
    from openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner import GetCatalogCategoryDeleteJobResponseCollectionDataInner
    from openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner_all_of_relationships import GetCatalogCategoryDeleteJobResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_item_list_response_collection import GetCatalogCategoryItemListResponseCollection
    from openapi_client.models.get_catalog_category_item_list_response_collection_data_inner import GetCatalogCategoryItemListResponseCollectionDataInner
    from openapi_client.models.get_catalog_category_response import GetCatalogCategoryResponse
    from openapi_client.models.get_catalog_category_response_collection import GetCatalogCategoryResponseCollection
    from openapi_client.models.get_catalog_category_response_collection_data_inner import GetCatalogCategoryResponseCollectionDataInner
    from openapi_client.models.get_catalog_category_response_collection_data_inner_all_of_relationships import GetCatalogCategoryResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner
    from openapi_client.models.get_catalog_category_update_job_response_compound_document import GetCatalogCategoryUpdateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_item_category_list_response_collection import GetCatalogItemCategoryListResponseCollection
    from openapi_client.models.get_catalog_item_category_list_response_collection_data_inner import GetCatalogItemCategoryListResponseCollectionDataInner
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document import GetCatalogItemCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner
    from openapi_client.models.get_catalog_item_create_job_response_compound_document import GetCatalogItemCreateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_item_delete_job_response import GetCatalogItemDeleteJobResponse
    from openapi_client.models.get_catalog_item_delete_job_response_collection import GetCatalogItemDeleteJobResponseCollection
    from openapi_client.models.get_catalog_item_delete_job_response_collection_data_inner import GetCatalogItemDeleteJobResponseCollectionDataInner
    from openapi_client.models.get_catalog_item_response_collection_compound_document import GetCatalogItemResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner import GetCatalogItemResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
    from openapi_client.models.get_catalog_item_response_compound_document import GetCatalogItemResponseCompoundDocument
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document import GetCatalogItemUpdateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner
    from openapi_client.models.get_catalog_item_update_job_response_compound_document import GetCatalogItemUpdateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document import GetCatalogVariantCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
    from openapi_client.models.get_catalog_variant_create_job_response_compound_document import GetCatalogVariantCreateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_variant_delete_job_response import GetCatalogVariantDeleteJobResponse
    from openapi_client.models.get_catalog_variant_delete_job_response_collection import GetCatalogVariantDeleteJobResponseCollection
    from openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner import GetCatalogVariantDeleteJobResponseCollectionDataInner
    from openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner_all_of_relationships import GetCatalogVariantDeleteJobResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_response import GetCatalogVariantResponse
    from openapi_client.models.get_catalog_variant_response_collection import GetCatalogVariantResponseCollection
    from openapi_client.models.get_catalog_variant_response_collection_data_inner import GetCatalogVariantResponseCollectionDataInner
    from openapi_client.models.get_catalog_variant_response_collection_data_inner_all_of_relationships import GetCatalogVariantResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document import GetCatalogVariantUpdateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
    from openapi_client.models.get_catalog_variant_update_job_response_compound_document import GetCatalogVariantUpdateJobResponseCompoundDocument
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document import GetCouponCodeCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodes
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes_data_inner import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodesDataInner
    from openapi_client.models.get_coupon_code_create_job_response_compound_document import GetCouponCodeCreateJobResponseCompoundDocument
    from openapi_client.models.get_coupon_code_relationship_coupon_response import GetCouponCodeRelationshipCouponResponse
    from openapi_client.models.get_coupon_code_relationship_coupon_response_data import GetCouponCodeRelationshipCouponResponseData
    from openapi_client.models.get_coupon_code_response_collection import GetCouponCodeResponseCollection
    from openapi_client.models.get_coupon_code_response_collection_compound_document import GetCouponCodeResponseCollectionCompoundDocument
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner import GetCouponCodeResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCoupon
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon_data import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponData
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_profile import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile
    from openapi_client.models.get_coupon_code_response_collection_data_inner import GetCouponCodeResponseCollectionDataInner
    from openapi_client.models.get_coupon_code_response_collection_data_inner_all_of_relationships import GetCouponCodeResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_coupon_code_response_compound_document import GetCouponCodeResponseCompoundDocument
    from openapi_client.models.get_coupon_relationship_coupon_codes_list_response_collection import GetCouponRelationshipCouponCodesListResponseCollection
    from openapi_client.models.get_coupon_relationship_coupon_codes_list_response_collection_data_inner import GetCouponRelationshipCouponCodesListResponseCollectionDataInner
    from openapi_client.models.get_coupon_response import GetCouponResponse
    from openapi_client.models.get_coupon_response_collection import GetCouponResponseCollection
    from openapi_client.models.get_event_metric_relationship_response import GetEventMetricRelationshipResponse
    from openapi_client.models.get_event_metric_relationship_response_data import GetEventMetricRelationshipResponseData
    from openapi_client.models.get_event_profile_relationship_response import GetEventProfileRelationshipResponse
    from openapi_client.models.get_event_profile_relationship_response_data import GetEventProfileRelationshipResponseData
    from openapi_client.models.get_event_response_collection_compound_document import GetEventResponseCollectionCompoundDocument
    from openapi_client.models.get_event_response_collection_compound_document_data_inner import GetEventResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributions
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions_data_inner import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributionsDataInner
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetric
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric_data import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetricData
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile_data import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfileData
    from openapi_client.models.get_event_response_compound_document import GetEventResponseCompoundDocument
    from openapi_client.models.get_flow_action_flow_message_relationship_response_collection import GetFlowActionFlowMessageRelationshipResponseCollection
    from openapi_client.models.get_flow_action_flow_relationship_response import GetFlowActionFlowRelationshipResponse
    from openapi_client.models.get_flow_action_response import GetFlowActionResponse
    from openapi_client.models.get_flow_action_response_collection import GetFlowActionResponseCollection
    from openapi_client.models.get_flow_action_response_collection_data_inner import GetFlowActionResponseCollectionDataInner
    from openapi_client.models.get_flow_action_response_collection_data_inner_all_of_relationships import GetFlowActionResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_flow_action_response_compound_document import GetFlowActionResponseCompoundDocument
    from openapi_client.models.get_flow_action_response_compound_document_data import GetFlowActionResponseCompoundDocumentData
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships import GetFlowActionResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlow
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessages
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages_data_inner import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessagesDataInner
    from openapi_client.models.get_flow_flow_action_relationship_list_response_collection import GetFlowFlowActionRelationshipListResponseCollection
    from openapi_client.models.get_flow_message_flow_action_relationship_response import GetFlowMessageFlowActionRelationshipResponse
    from openapi_client.models.get_flow_message_response_collection import GetFlowMessageResponseCollection
    from openapi_client.models.get_flow_message_response_collection_data_inner import GetFlowMessageResponseCollectionDataInner
    from openapi_client.models.get_flow_message_response_collection_data_inner_all_of_relationships import GetFlowMessageResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_flow_message_response_compound_document import GetFlowMessageResponseCompoundDocument
    from openapi_client.models.get_flow_message_response_compound_document_data import GetFlowMessageResponseCompoundDocumentData
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships import GetFlowMessageResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_flow_action import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsFlowAction
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template_data import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData
    from openapi_client.models.get_flow_message_template_relationship_response import GetFlowMessageTemplateRelationshipResponse
    from openapi_client.models.get_flow_response import GetFlowResponse
    from openapi_client.models.get_flow_response_collection import GetFlowResponseCollection
    from openapi_client.models.get_flow_response_collection_compound_document import GetFlowResponseCollectionCompoundDocument
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner import GetFlowResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActions
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions_data_inner import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActionsDataInner
    from openapi_client.models.get_flow_response_collection_data_inner import GetFlowResponseCollectionDataInner
    from openapi_client.models.get_flow_response_collection_data_inner_all_of_relationships import GetFlowResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_flow_response_compound_document import GetFlowResponseCompoundDocument
    from openapi_client.models.get_flow_tag_relationship_list_response_collection import GetFlowTagRelationshipListResponseCollection
    from openapi_client.models.get_form_form_version_relationships_response_collection import GetFormFormVersionRelationshipsResponseCollection
    from openapi_client.models.get_form_response import GetFormResponse
    from openapi_client.models.get_form_response_collection_compound_document import GetFormResponseCollectionCompoundDocument
    from openapi_client.models.get_form_response_collection_compound_document_data_inner import GetFormResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_form_response_collection_compound_document_data_inner_all_of_relationships import GetFormResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_form_response_compound_document import GetFormResponseCompoundDocument
    from openapi_client.models.get_form_response_compound_document_data import GetFormResponseCompoundDocumentData
    from openapi_client.models.get_form_response_compound_document_data_all_of_relationships import GetFormResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions import GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersions
    from openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions_data_inner import GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersionsDataInner
    from openapi_client.models.get_form_version_form_relationship_response import GetFormVersionFormRelationshipResponse
    from openapi_client.models.get_form_version_form_relationship_response_data import GetFormVersionFormRelationshipResponseData
    from openapi_client.models.get_form_version_response import GetFormVersionResponse
    from openapi_client.models.get_form_version_response_collection import GetFormVersionResponseCollection
    from openapi_client.models.get_image_response import GetImageResponse
    from openapi_client.models.get_image_response_collection import GetImageResponseCollection
    from openapi_client.models.get_import_error_response_collection import GetImportErrorResponseCollection
    from openapi_client.models.get_list_flow_triggers_relationships_response_collection import GetListFlowTriggersRelationshipsResponseCollection
    from openapi_client.models.get_list_list_response_collection_compound_document import GetListListResponseCollectionCompoundDocument
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner import GetListListResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTags
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags_data_inner import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagsDataInner
    from openapi_client.models.get_list_member_response_collection import GetListMemberResponseCollection
    from openapi_client.models.get_list_member_response_collection_data_inner import GetListMemberResponseCollectionDataInner
    from openapi_client.models.get_list_relationships_response_collection import GetListRelationshipsResponseCollection
    from openapi_client.models.get_list_response_collection import GetListResponseCollection
    from openapi_client.models.get_list_response_collection_data_inner import GetListResponseCollectionDataInner
    from openapi_client.models.get_list_response_collection_data_inner_all_of_relationships import GetListResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_list_retrieve_response_compound_document import GetListRetrieveResponseCompoundDocument
    from openapi_client.models.get_list_retrieve_response_compound_document_data import GetListRetrieveResponseCompoundDocumentData
    from openapi_client.models.get_list_tag_relationship_list_response_collection import GetListTagRelationshipListResponseCollection
    from openapi_client.models.get_metric_flow_triggers_relationships_response_collection import GetMetricFlowTriggersRelationshipsResponseCollection
    from openapi_client.models.get_metric_property_relationship_metric_response import GetMetricPropertyRelationshipMetricResponse
    from openapi_client.models.get_metric_property_relationship_metric_response_data import GetMetricPropertyRelationshipMetricResponseData
    from openapi_client.models.get_metric_property_response_collection import GetMetricPropertyResponseCollection
    from openapi_client.models.get_metric_property_response_collection_data_inner import GetMetricPropertyResponseCollectionDataInner
    from openapi_client.models.get_metric_property_response_collection_data_inner_all_of_relationships import GetMetricPropertyResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_metric_property_response_compound_document import GetMetricPropertyResponseCompoundDocument
    from openapi_client.models.get_metric_property_response_compound_document_data import GetMetricPropertyResponseCompoundDocumentData
    from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetric
    from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric_data import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetricData
    from openapi_client.models.get_metric_relationship_metric_property_response_collection import GetMetricRelationshipMetricPropertyResponseCollection
    from openapi_client.models.get_metric_relationship_metric_property_response_collection_data_inner import GetMetricRelationshipMetricPropertyResponseCollectionDataInner
    from openapi_client.models.get_metric_response import GetMetricResponse
    from openapi_client.models.get_metric_response_collection_compound_document import GetMetricResponseCollectionCompoundDocument
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner import GetMetricResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships import GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships_flow_triggers import GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowTriggers
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships_flow_triggers_data_inner import GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowTriggersDataInner
    from openapi_client.models.get_metric_response_compound_document import GetMetricResponseCompoundDocument
    from openapi_client.models.get_metric_response_data import GetMetricResponseData
    from openapi_client.models.get_metric_response_data_all_of_relationships import GetMetricResponseDataAllOfRelationships
    from openapi_client.models.get_profile_import_job_list_relationships_response_collection import GetProfileImportJobListRelationshipsResponseCollection
    from openapi_client.models.get_profile_import_job_profile_relationships_response_collection import GetProfileImportJobProfileRelationshipsResponseCollection
    from openapi_client.models.get_profile_import_job_response_collection_compound_document import GetProfileImportJobResponseCollectionCompoundDocument
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner import GetProfileImportJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_import_errors import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsImportErrors
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsLists
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists_data_inner import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsListsDataInner
    from openapi_client.models.get_profile_import_job_response_compound_document import GetProfileImportJobResponseCompoundDocument
    from openapi_client.models.get_profile_list_relationships_response_collection import GetProfileListRelationshipsResponseCollection
    from openapi_client.models.get_profile_response import GetProfileResponse
    from openapi_client.models.get_profile_response_collection import GetProfileResponseCollection
    from openapi_client.models.get_profile_response_collection_compound_document import GetProfileResponseCollectionCompoundDocument
    from openapi_client.models.get_profile_response_compound_document import GetProfileResponseCompoundDocument
    from openapi_client.models.get_profile_response_compound_document_data import GetProfileResponseCompoundDocumentData
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships import GetProfileResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists import GetProfileResponseCompoundDocumentDataAllOfRelationshipsLists
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists_data_inner import GetProfileResponseCompoundDocumentDataAllOfRelationshipsListsDataInner
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments import GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegments
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments_data_inner import GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegmentsDataInner
    from openapi_client.models.get_profile_response_data import GetProfileResponseData
    from openapi_client.models.get_profile_response_data_all_of_relationships import GetProfileResponseDataAllOfRelationships
    from openapi_client.models.get_profile_segment_relationships_response_collection import GetProfileSegmentRelationshipsResponseCollection
    from openapi_client.models.get_review_response_dto20240715_collection_compound_document import GetReviewResponseDTO20240715CollectionCompoundDocument
    from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInner
    from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner_all_of_relationships import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner_all_of_relationships_events import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInnerAllOfRelationshipsEvents
    from openapi_client.models.get_review_response_dto20240715_collection_compound_document_data_inner_all_of_relationships_events_data_inner import GetReviewResponseDTO20240715CollectionCompoundDocumentDataInnerAllOfRelationshipsEventsDataInner
    from openapi_client.models.get_review_response_dto20240715_compound_document import GetReviewResponseDTO20240715CompoundDocument
    from openapi_client.models.get_segment_flow_triggers_relationships_response_collection import GetSegmentFlowTriggersRelationshipsResponseCollection
    from openapi_client.models.get_segment_list_response_collection_compound_document import GetSegmentListResponseCollectionCompoundDocument
    from openapi_client.models.get_segment_list_response_collection_compound_document_data_inner import GetSegmentListResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_segment_member_response_collection import GetSegmentMemberResponseCollection
    from openapi_client.models.get_segment_member_response_collection_data_inner import GetSegmentMemberResponseCollectionDataInner
    from openapi_client.models.get_segment_relationships_response_collection import GetSegmentRelationshipsResponseCollection
    from openapi_client.models.get_segment_response_collection import GetSegmentResponseCollection
    from openapi_client.models.get_segment_response_collection_data_inner import GetSegmentResponseCollectionDataInner
    from openapi_client.models.get_segment_retrieve_response_compound_document import GetSegmentRetrieveResponseCompoundDocument
    from openapi_client.models.get_segment_retrieve_response_compound_document_data import GetSegmentRetrieveResponseCompoundDocumentData
    from openapi_client.models.get_segment_tag_relationship_list_response_collection import GetSegmentTagRelationshipListResponseCollection
    from openapi_client.models.get_tag_campaign_relationships_response_collection import GetTagCampaignRelationshipsResponseCollection
    from openapi_client.models.get_tag_campaign_relationships_response_collection_data_inner import GetTagCampaignRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_flow_relationships_response_collection import GetTagFlowRelationshipsResponseCollection
    from openapi_client.models.get_tag_flow_relationships_response_collection_data_inner import GetTagFlowRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_group_response import GetTagGroupResponse
    from openapi_client.models.get_tag_group_response_collection import GetTagGroupResponseCollection
    from openapi_client.models.get_tag_group_response_collection_data_inner import GetTagGroupResponseCollectionDataInner
    from openapi_client.models.get_tag_group_response_collection_data_inner_all_of_relationships import GetTagGroupResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_tag_group_tag_relationships_response_collection import GetTagGroupTagRelationshipsResponseCollection
    from openapi_client.models.get_tag_group_tag_relationships_response_collection_data_inner import GetTagGroupTagRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_list_relationships_response_collection import GetTagListRelationshipsResponseCollection
    from openapi_client.models.get_tag_list_relationships_response_collection_data_inner import GetTagListRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_response_collection import GetTagResponseCollection
    from openapi_client.models.get_tag_response_collection_compound_document import GetTagResponseCollectionCompoundDocument
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner import GetTagResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroup
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group_data import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroupData
    from openapi_client.models.get_tag_response_collection_data_inner import GetTagResponseCollectionDataInner
    from openapi_client.models.get_tag_response_collection_data_inner_all_of_relationships import GetTagResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_tag_response_compound_document import GetTagResponseCompoundDocument
    from openapi_client.models.get_tag_segment_relationships_response_collection import GetTagSegmentRelationshipsResponseCollection
    from openapi_client.models.get_tag_segment_relationships_response_collection_data_inner import GetTagSegmentRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_tag_group_relationships_response import GetTagTagGroupRelationshipsResponse
    from openapi_client.models.get_tag_tag_group_relationships_response_data import GetTagTagGroupRelationshipsResponseData
    from openapi_client.models.get_template_response import GetTemplateResponse
    from openapi_client.models.get_template_response_collection import GetTemplateResponseCollection
    from openapi_client.models.get_tracking_setting_response import GetTrackingSettingResponse
    from openapi_client.models.get_tracking_setting_response_collection import GetTrackingSettingResponseCollection
    from openapi_client.models.get_universal_content_response import GetUniversalContentResponse
    from openapi_client.models.get_universal_content_response_collection import GetUniversalContentResponseCollection
    from openapi_client.models.get_webhook_response_collection_compound_document import GetWebhookResponseCollectionCompoundDocument
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner import GetWebhookResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopics
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics_data_inner import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopicsDataInner
    from openapi_client.models.get_webhook_response_compound_document import GetWebhookResponseCompoundDocument
    from openapi_client.models.get_webhook_topic_response import GetWebhookTopicResponse
    from openapi_client.models.get_webhook_topic_response_collection import GetWebhookTopicResponseCollection
    from openapi_client.models.image_create_query import ImageCreateQuery
    from openapi_client.models.image_create_query_resource_object import ImageCreateQueryResourceObject
    from openapi_client.models.image_create_query_resource_object_attributes import ImageCreateQueryResourceObjectAttributes
    from openapi_client.models.image_enum import ImageEnum
    from openapi_client.models.image_partial_update_query import ImagePartialUpdateQuery
    from openapi_client.models.image_partial_update_query_resource_object import ImagePartialUpdateQueryResourceObject
    from openapi_client.models.image_partial_update_query_resource_object_attributes import ImagePartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.image_response_object_resource import ImageResponseObjectResource
    from openapi_client.models.image_response_object_resource_attributes import ImageResponseObjectResourceAttributes
    from openapi_client.models.import_error_enum import ImportErrorEnum
    from openapi_client.models.import_error_response_object_resource import ImportErrorResponseObjectResource
    from openapi_client.models.import_error_response_object_resource_attributes import ImportErrorResponseObjectResourceAttributes
    from openapi_client.models.list_create_query import ListCreateQuery
    from openapi_client.models.list_create_query_resource_object import ListCreateQueryResourceObject
    from openapi_client.models.list_create_query_resource_object_attributes import ListCreateQueryResourceObjectAttributes
    from openapi_client.models.list_enum import ListEnum
    from openapi_client.models.list_list_response_object_resource import ListListResponseObjectResource
    from openapi_client.models.list_list_response_object_resource_attributes import ListListResponseObjectResourceAttributes
    from openapi_client.models.list_member_response_object_resource_attributes import ListMemberResponseObjectResourceAttributes
    from openapi_client.models.list_member_response_object_resource_extended import ListMemberResponseObjectResourceExtended
    from openapi_client.models.list_member_response_object_resource_extended_attributes import ListMemberResponseObjectResourceExtendedAttributes
    from openapi_client.models.list_members_add_query import ListMembersAddQuery
    from openapi_client.models.list_members_delete_query import ListMembersDeleteQuery
    from openapi_client.models.list_partial_update_query import ListPartialUpdateQuery
    from openapi_client.models.list_partial_update_query_resource_object import ListPartialUpdateQueryResourceObject
    from openapi_client.models.list_response_object_resource import ListResponseObjectResource
    from openapi_client.models.list_retrieve_response_object_resource_attributes import ListRetrieveResponseObjectResourceAttributes
    from openapi_client.models.list_retrieve_response_object_resource_extended import ListRetrieveResponseObjectResourceExtended
    from openapi_client.models.list_retrieve_response_object_resource_extended_attributes import ListRetrieveResponseObjectResourceExtendedAttributes
    from openapi_client.models.metric_aggregate_enum import MetricAggregateEnum
    from openapi_client.models.metric_aggregate_query import MetricAggregateQuery
    from openapi_client.models.metric_aggregate_query_resource_object import MetricAggregateQueryResourceObject
    from openapi_client.models.metric_aggregate_query_resource_object_attributes import MetricAggregateQueryResourceObjectAttributes
    from openapi_client.models.metric_aggregate_row_dto import MetricAggregateRowDTO
    from openapi_client.models.metric_create_query_resource_object import MetricCreateQueryResourceObject
    from openapi_client.models.metric_create_query_resource_object_attributes import MetricCreateQueryResourceObjectAttributes
    from openapi_client.models.metric_enum import MetricEnum
    from openapi_client.models.metric_property_enum import MetricPropertyEnum
    from openapi_client.models.metric_property_response_object_resource_attributes import MetricPropertyResponseObjectResourceAttributes
    from openapi_client.models.metric_property_response_object_resource_extended import MetricPropertyResponseObjectResourceExtended
    from openapi_client.models.metric_property_response_object_resource_extended_attributes import MetricPropertyResponseObjectResourceExtendedAttributes
    from openapi_client.models.metric_response_object_resource import MetricResponseObjectResource
    from openapi_client.models.metric_response_object_resource_attributes import MetricResponseObjectResourceAttributes
    from openapi_client.models.object_links import ObjectLinks
    from openapi_client.models.only_related_links import OnlyRelatedLinks
    from openapi_client.models.onsite_profile_create_query_resource_object import OnsiteProfileCreateQueryResourceObject
    from openapi_client.models.onsite_profile_create_query_resource_object_attributes import OnsiteProfileCreateQueryResourceObjectAttributes
    from openapi_client.models.onsite_profile_meta import OnsiteProfileMeta
    from openapi_client.models.patch_campaign_message_response import PatchCampaignMessageResponse
    from openapi_client.models.patch_campaign_response import PatchCampaignResponse
    from openapi_client.models.patch_catalog_category_response import PatchCatalogCategoryResponse
    from openapi_client.models.patch_catalog_item_response import PatchCatalogItemResponse
    from openapi_client.models.patch_catalog_variant_response import PatchCatalogVariantResponse
    from openapi_client.models.patch_coupon_code_response import PatchCouponCodeResponse
    from openapi_client.models.patch_coupon_response import PatchCouponResponse
    from openapi_client.models.patch_flow_response import PatchFlowResponse
    from openapi_client.models.patch_flow_response_data import PatchFlowResponseData
    from openapi_client.models.patch_image_response import PatchImageResponse
    from openapi_client.models.patch_list_partial_update_response import PatchListPartialUpdateResponse
    from openapi_client.models.patch_profile_response import PatchProfileResponse
    from openapi_client.models.patch_segment_partial_update_response import PatchSegmentPartialUpdateResponse
    from openapi_client.models.patch_tag_group_response import PatchTagGroupResponse
    from openapi_client.models.patch_template_response import PatchTemplateResponse
    from openapi_client.models.patch_tracking_setting_response import PatchTrackingSettingResponse
    from openapi_client.models.patch_tracking_setting_response_data import PatchTrackingSettingResponseData
    from openapi_client.models.patch_universal_content_response import PatchUniversalContentResponse
    from openapi_client.models.patch_webhook_response import PatchWebhookResponse
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response import PostBulkProfileSuppressionsCreateJobResponse
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data import PostBulkProfileSuppressionsCreateJobResponseData
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_attributes import PostBulkProfileSuppressionsCreateJobResponseDataAttributes
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships import PostBulkProfileSuppressionsCreateJobResponseDataRelationships
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsLists
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists_data_inner import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsListsDataInner
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegments
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments_data_inner import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegmentsDataInner
    from openapi_client.models.post_bulk_profile_suppressions_remove_job_response import PostBulkProfileSuppressionsRemoveJobResponse
    from openapi_client.models.post_bulk_profile_suppressions_remove_job_response_data import PostBulkProfileSuppressionsRemoveJobResponseData
    from openapi_client.models.post_campaign_message_response import PostCampaignMessageResponse
    from openapi_client.models.post_campaign_message_response_data import PostCampaignMessageResponseData
    from openapi_client.models.post_campaign_message_response_data_attributes import PostCampaignMessageResponseDataAttributes
    from openapi_client.models.post_campaign_recipient_estimation_job_response import PostCampaignRecipientEstimationJobResponse
    from openapi_client.models.post_campaign_recipient_estimation_job_response_data import PostCampaignRecipientEstimationJobResponseData
    from openapi_client.models.post_campaign_recipient_estimation_job_response_data_attributes import PostCampaignRecipientEstimationJobResponseDataAttributes
    from openapi_client.models.post_campaign_response import PostCampaignResponse
    from openapi_client.models.post_campaign_response_data import PostCampaignResponseData
    from openapi_client.models.post_campaign_response_data_attributes import PostCampaignResponseDataAttributes
    from openapi_client.models.post_campaign_send_job_response import PostCampaignSendJobResponse
    from openapi_client.models.post_campaign_send_job_response_data import PostCampaignSendJobResponseData
    from openapi_client.models.post_campaign_send_job_response_data_attributes import PostCampaignSendJobResponseDataAttributes
    from openapi_client.models.post_campaign_values_response_dto import PostCampaignValuesResponseDTO
    from openapi_client.models.post_campaign_values_response_dto_data import PostCampaignValuesResponseDTOData
    from openapi_client.models.post_campaign_values_response_dto_data_attributes import PostCampaignValuesResponseDTODataAttributes
    from openapi_client.models.post_campaign_values_response_dto_data_relationships import PostCampaignValuesResponseDTODataRelationships
    from openapi_client.models.post_catalog_category_create_job_response import PostCatalogCategoryCreateJobResponse
    from openapi_client.models.post_catalog_category_create_job_response_data import PostCatalogCategoryCreateJobResponseData
    from openapi_client.models.post_catalog_category_delete_job_response import PostCatalogCategoryDeleteJobResponse
    from openapi_client.models.post_catalog_category_delete_job_response_data import PostCatalogCategoryDeleteJobResponseData
    from openapi_client.models.post_catalog_category_delete_job_response_data_relationships import PostCatalogCategoryDeleteJobResponseDataRelationships
    from openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories import PostCatalogCategoryDeleteJobResponseDataRelationshipsCategories
    from openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories_data_inner import PostCatalogCategoryDeleteJobResponseDataRelationshipsCategoriesDataInner
    from openapi_client.models.post_catalog_category_response import PostCatalogCategoryResponse
    from openapi_client.models.post_catalog_category_response_data import PostCatalogCategoryResponseData
    from openapi_client.models.post_catalog_category_response_data_relationships import PostCatalogCategoryResponseDataRelationships
    from openapi_client.models.post_catalog_category_response_data_relationships_items import PostCatalogCategoryResponseDataRelationshipsItems
    from openapi_client.models.post_catalog_category_update_job_response import PostCatalogCategoryUpdateJobResponse
    from openapi_client.models.post_catalog_category_update_job_response_data import PostCatalogCategoryUpdateJobResponseData
    from openapi_client.models.post_catalog_item_create_job_response import PostCatalogItemCreateJobResponse
    from openapi_client.models.post_catalog_item_create_job_response_data import PostCatalogItemCreateJobResponseData
    from openapi_client.models.post_catalog_item_delete_job_response import PostCatalogItemDeleteJobResponse
    from openapi_client.models.post_catalog_item_delete_job_response_data import PostCatalogItemDeleteJobResponseData
    from openapi_client.models.post_catalog_item_delete_job_response_data_relationships import PostCatalogItemDeleteJobResponseDataRelationships
    from openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items import PostCatalogItemDeleteJobResponseDataRelationshipsItems
    from openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items_data_inner import PostCatalogItemDeleteJobResponseDataRelationshipsItemsDataInner
    from openapi_client.models.post_catalog_item_response import PostCatalogItemResponse
    from openapi_client.models.post_catalog_item_response_data import PostCatalogItemResponseData
    from openapi_client.models.post_catalog_item_update_job_response import PostCatalogItemUpdateJobResponse
    from openapi_client.models.post_catalog_item_update_job_response_data import PostCatalogItemUpdateJobResponseData
    from openapi_client.models.post_catalog_variant_create_job_response import PostCatalogVariantCreateJobResponse
    from openapi_client.models.post_catalog_variant_create_job_response_data import PostCatalogVariantCreateJobResponseData
    from openapi_client.models.post_catalog_variant_delete_job_response import PostCatalogVariantDeleteJobResponse
    from openapi_client.models.post_catalog_variant_delete_job_response_data import PostCatalogVariantDeleteJobResponseData
    from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships import PostCatalogVariantDeleteJobResponseDataRelationships
    from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants import PostCatalogVariantDeleteJobResponseDataRelationshipsVariants
    from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants_data_inner import PostCatalogVariantDeleteJobResponseDataRelationshipsVariantsDataInner
    from openapi_client.models.post_catalog_variant_response import PostCatalogVariantResponse
    from openapi_client.models.post_catalog_variant_response_data import PostCatalogVariantResponseData
    from openapi_client.models.post_catalog_variant_response_data_relationships import PostCatalogVariantResponseDataRelationships
    from openapi_client.models.post_catalog_variant_response_data_relationships_item import PostCatalogVariantResponseDataRelationshipsItem
    from openapi_client.models.post_catalog_variant_response_data_relationships_item_data import PostCatalogVariantResponseDataRelationshipsItemData
    from openapi_client.models.post_catalog_variant_update_job_response import PostCatalogVariantUpdateJobResponse
    from openapi_client.models.post_catalog_variant_update_job_response_data import PostCatalogVariantUpdateJobResponseData
    from openapi_client.models.post_coupon_code_create_job_response import PostCouponCodeCreateJobResponse
    from openapi_client.models.post_coupon_code_create_job_response_data import PostCouponCodeCreateJobResponseData
    from openapi_client.models.post_coupon_code_create_job_response_data_attributes import PostCouponCodeCreateJobResponseDataAttributes
    from openapi_client.models.post_coupon_code_response import PostCouponCodeResponse
    from openapi_client.models.post_coupon_code_response_data import PostCouponCodeResponseData
    from openapi_client.models.post_coupon_code_response_data_relationships import PostCouponCodeResponseDataRelationships
    from openapi_client.models.post_coupon_code_response_data_relationships_profile import PostCouponCodeResponseDataRelationshipsProfile
    from openapi_client.models.post_coupon_code_response_data_relationships_profile_data import PostCouponCodeResponseDataRelationshipsProfileData
    from openapi_client.models.post_coupon_response import PostCouponResponse
    from openapi_client.models.post_coupon_response_data import PostCouponResponseData
    from openapi_client.models.post_coupon_response_data_attributes import PostCouponResponseDataAttributes
    from openapi_client.models.post_flow_series_response_dto import PostFlowSeriesResponseDTO
    from openapi_client.models.post_flow_series_response_dto_data import PostFlowSeriesResponseDTOData
    from openapi_client.models.post_flow_series_response_dto_data_attributes import PostFlowSeriesResponseDTODataAttributes
    from openapi_client.models.post_flow_values_response_dto import PostFlowValuesResponseDTO
    from openapi_client.models.post_flow_values_response_dto_data import PostFlowValuesResponseDTOData
    from openapi_client.models.post_flow_values_response_dto_data_attributes import PostFlowValuesResponseDTODataAttributes
    from openapi_client.models.post_flow_values_response_dto_data_relationships import PostFlowValuesResponseDTODataRelationships
    from openapi_client.models.post_form_series_response_dto import PostFormSeriesResponseDTO
    from openapi_client.models.post_form_series_response_dto_data import PostFormSeriesResponseDTOData
    from openapi_client.models.post_form_series_response_dto_data_attributes import PostFormSeriesResponseDTODataAttributes
    from openapi_client.models.post_form_values_response_dto import PostFormValuesResponseDTO
    from openapi_client.models.post_form_values_response_dto_data import PostFormValuesResponseDTOData
    from openapi_client.models.post_form_values_response_dto_data_attributes import PostFormValuesResponseDTODataAttributes
    from openapi_client.models.post_image_response import PostImageResponse
    from openapi_client.models.post_image_response_data import PostImageResponseData
    from openapi_client.models.post_image_response_data_attributes import PostImageResponseDataAttributes
    from openapi_client.models.post_list_create_response import PostListCreateResponse
    from openapi_client.models.post_list_create_response_data import PostListCreateResponseData
    from openapi_client.models.post_list_create_response_data_relationships import PostListCreateResponseDataRelationships
    from openapi_client.models.post_list_create_response_data_relationships_profiles import PostListCreateResponseDataRelationshipsProfiles
    from openapi_client.models.post_metric_aggregate_response import PostMetricAggregateResponse
    from openapi_client.models.post_metric_aggregate_response_data import PostMetricAggregateResponseData
    from openapi_client.models.post_metric_aggregate_response_data_attributes import PostMetricAggregateResponseDataAttributes
    from openapi_client.models.post_profile_import_job_response import PostProfileImportJobResponse
    from openapi_client.models.post_profile_import_job_response_data import PostProfileImportJobResponseData
    from openapi_client.models.post_profile_import_job_response_data_attributes import PostProfileImportJobResponseDataAttributes
    from openapi_client.models.post_profile_import_job_response_data_relationships import PostProfileImportJobResponseDataRelationships
    from openapi_client.models.post_profile_import_job_response_data_relationships_import_errors import PostProfileImportJobResponseDataRelationshipsImportErrors
    from openapi_client.models.post_profile_import_job_response_data_relationships_import_errors_data_inner import PostProfileImportJobResponseDataRelationshipsImportErrorsDataInner
    from openapi_client.models.post_profile_import_job_response_data_relationships_profiles import PostProfileImportJobResponseDataRelationshipsProfiles
    from openapi_client.models.post_profile_import_job_response_data_relationships_profiles_data_inner import PostProfileImportJobResponseDataRelationshipsProfilesDataInner
    from openapi_client.models.post_profile_merge_response import PostProfileMergeResponse
    from openapi_client.models.post_profile_merge_response_data import PostProfileMergeResponseData
    from openapi_client.models.post_profile_response import PostProfileResponse
    from openapi_client.models.post_profile_response_data import PostProfileResponseData
    from openapi_client.models.post_profile_response_data_attributes import PostProfileResponseDataAttributes
    from openapi_client.models.post_segment_create_response import PostSegmentCreateResponse
    from openapi_client.models.post_segment_create_response_data import PostSegmentCreateResponseData
    from openapi_client.models.post_segment_series_response_dto import PostSegmentSeriesResponseDTO
    from openapi_client.models.post_segment_series_response_dto_data import PostSegmentSeriesResponseDTOData
    from openapi_client.models.post_segment_series_response_dto_data_attributes import PostSegmentSeriesResponseDTODataAttributes
    from openapi_client.models.post_segment_values_response_dto import PostSegmentValuesResponseDTO
    from openapi_client.models.post_segment_values_response_dto_data import PostSegmentValuesResponseDTOData
    from openapi_client.models.post_segment_values_response_dto_data_attributes import PostSegmentValuesResponseDTODataAttributes
    from openapi_client.models.post_tag_group_response import PostTagGroupResponse
    from openapi_client.models.post_tag_group_response_data import PostTagGroupResponseData
    from openapi_client.models.post_tag_group_response_data_attributes import PostTagGroupResponseDataAttributes
    from openapi_client.models.post_tag_group_response_data_relationships import PostTagGroupResponseDataRelationships
    from openapi_client.models.post_tag_response import PostTagResponse
    from openapi_client.models.post_tag_response_data import PostTagResponseData
    from openapi_client.models.post_tag_response_data_attributes import PostTagResponseDataAttributes
    from openapi_client.models.post_tag_response_data_relationships import PostTagResponseDataRelationships
    from openapi_client.models.post_tag_response_data_relationships_campaigns import PostTagResponseDataRelationshipsCampaigns
    from openapi_client.models.post_template_response import PostTemplateResponse
    from openapi_client.models.post_template_response_data import PostTemplateResponseData
    from openapi_client.models.post_template_response_data_attributes import PostTemplateResponseDataAttributes
    from openapi_client.models.post_universal_content_response import PostUniversalContentResponse
    from openapi_client.models.post_universal_content_response_data import PostUniversalContentResponseData
    from openapi_client.models.post_universal_content_response_data_attributes import PostUniversalContentResponseDataAttributes
    from openapi_client.models.post_webhook_response import PostWebhookResponse
    from openapi_client.models.post_webhook_response_data import PostWebhookResponseData
    from openapi_client.models.post_webhook_response_data_attributes import PostWebhookResponseDataAttributes
    from openapi_client.models.predictive_analytics import PredictiveAnalytics
    from openapi_client.models.profile_bulk_import_job_enum import ProfileBulkImportJobEnum
    from openapi_client.models.profile_create_query import ProfileCreateQuery
    from openapi_client.models.profile_create_query_resource_object import ProfileCreateQueryResourceObject
    from openapi_client.models.profile_create_query_resource_object_attributes import ProfileCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_enum import ProfileEnum
    from openapi_client.models.profile_identifier_dto_resource_object import ProfileIdentifierDTOResourceObject
    from openapi_client.models.profile_identifier_dto_resource_object_attributes import ProfileIdentifierDTOResourceObjectAttributes
    from openapi_client.models.profile_import_job_create_query import ProfileImportJobCreateQuery
    from openapi_client.models.profile_import_job_create_query_resource_object import ProfileImportJobCreateQueryResourceObject
    from openapi_client.models.profile_import_job_create_query_resource_object_attributes import ProfileImportJobCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_import_job_create_query_resource_object_attributes_profiles import ProfileImportJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.profile_import_job_create_query_resource_object_relationships import ProfileImportJobCreateQueryResourceObjectRelationships
    from openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists import ProfileImportJobCreateQueryResourceObjectRelationshipsLists
    from openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists_data_inner import ProfileImportJobCreateQueryResourceObjectRelationshipsListsDataInner
    from openapi_client.models.profile_import_job_response_object_resource import ProfileImportJobResponseObjectResource
    from openapi_client.models.profile_import_job_response_object_resource_attributes import ProfileImportJobResponseObjectResourceAttributes
    from openapi_client.models.profile_location import ProfileLocation
    from openapi_client.models.profile_merge_enum import ProfileMergeEnum
    from openapi_client.models.profile_merge_query import ProfileMergeQuery
    from openapi_client.models.profile_merge_query_resource_object import ProfileMergeQueryResourceObject
    from openapi_client.models.profile_merge_query_resource_object_relationships import ProfileMergeQueryResourceObjectRelationships
    from openapi_client.models.profile_merge_query_resource_object_relationships_profiles import ProfileMergeQueryResourceObjectRelationshipsProfiles
    from openapi_client.models.profile_merge_query_resource_object_relationships_profiles_data_inner import ProfileMergeQueryResourceObjectRelationshipsProfilesDataInner
    from openapi_client.models.profile_meta import ProfileMeta
    from openapi_client.models.profile_meta_patch_properties import ProfileMetaPatchProperties
    from openapi_client.models.profile_partial_update_query import ProfilePartialUpdateQuery
    from openapi_client.models.profile_partial_update_query_resource_object import ProfilePartialUpdateQueryResourceObject
    from openapi_client.models.profile_partial_update_query_resource_object_attributes import ProfilePartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.profile_response_object_resource_attributes import ProfileResponseObjectResourceAttributes
    from openapi_client.models.profile_response_object_resource_extended import ProfileResponseObjectResourceExtended
    from openapi_client.models.profile_response_object_resource_extended_attributes import ProfileResponseObjectResourceExtendedAttributes
    from openapi_client.models.profile_subscription_bulk_create_job_enum import ProfileSubscriptionBulkCreateJobEnum
    from openapi_client.models.profile_subscription_bulk_delete_job_enum import ProfileSubscriptionBulkDeleteJobEnum
    from openapi_client.models.profile_subscription_create_query_resource_object import ProfileSubscriptionCreateQueryResourceObject
    from openapi_client.models.profile_subscription_create_query_resource_object_attributes import ProfileSubscriptionCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_subscription_delete_query_resource_object import ProfileSubscriptionDeleteQueryResourceObject
    from openapi_client.models.profile_subscription_delete_query_resource_object_attributes import ProfileSubscriptionDeleteQueryResourceObjectAttributes
    from openapi_client.models.profile_suppression_bulk_create_job_enum import ProfileSuppressionBulkCreateJobEnum
    from openapi_client.models.profile_suppression_bulk_delete_job_enum import ProfileSuppressionBulkDeleteJobEnum
    from openapi_client.models.profile_suppression_create_query_resource_object import ProfileSuppressionCreateQueryResourceObject
    from openapi_client.models.profile_suppression_create_query_resource_object_attributes import ProfileSuppressionCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_suppression_delete_query_resource_object import ProfileSuppressionDeleteQueryResourceObject
    from openapi_client.models.profile_suppression_delete_query_resource_object_attributes import ProfileSuppressionDeleteQueryResourceObjectAttributes
    from openapi_client.models.profile_upsert_query import ProfileUpsertQuery
    from openapi_client.models.profile_upsert_query_resource_object import ProfileUpsertQueryResourceObject
    from openapi_client.models.profile_upsert_query_resource_object_attributes import ProfileUpsertQueryResourceObjectAttributes
    from openapi_client.models.push_channel import PushChannel
    from openapi_client.models.push_marketing import PushMarketing
    from openapi_client.models.push_profile_upsert_query_resource_object import PushProfileUpsertQueryResourceObject
    from openapi_client.models.push_profile_upsert_query_resource_object_attributes import PushProfileUpsertQueryResourceObjectAttributes
    from openapi_client.models.push_token_create_query import PushTokenCreateQuery
    from openapi_client.models.push_token_create_query_resource_object import PushTokenCreateQueryResourceObject
    from openapi_client.models.push_token_create_query_resource_object_attributes import PushTokenCreateQueryResourceObjectAttributes
    from openapi_client.models.push_token_create_query_resource_object_attributes_profile import PushTokenCreateQueryResourceObjectAttributesProfile
    from openapi_client.models.push_token_enum import PushTokenEnum
    from openapi_client.models.relationship_links import RelationshipLinks
    from openapi_client.models.render_options_sub_object import RenderOptionsSubObject
    from openapi_client.models.review_enum import ReviewEnum
    from openapi_client.models.review_product_dto import ReviewProductDTO
    from openapi_client.models.review_public_reply import ReviewPublicReply
    from openapi_client.models.review_response_dto20240715_object_resource import ReviewResponseDTO20240715ObjectResource
    from openapi_client.models.review_response_dto20240715_object_resource_attributes import ReviewResponseDTO20240715ObjectResourceAttributes
    from openapi_client.models.sms_render_options import SMSRenderOptions
    from openapi_client.models.sms_subscription_parameters import SMSSubscriptionParameters
    from openapi_client.models.sto_schedule_options import STOScheduleOptions
    from openapi_client.models.segment_create_query import SegmentCreateQuery
    from openapi_client.models.segment_create_query_resource_object import SegmentCreateQueryResourceObject
    from openapi_client.models.segment_create_query_resource_object_attributes import SegmentCreateQueryResourceObjectAttributes
    from openapi_client.models.segment_definition import SegmentDefinition
    from openapi_client.models.segment_enum import SegmentEnum
    from openapi_client.models.segment_list_response_object_resource import SegmentListResponseObjectResource
    from openapi_client.models.segment_list_response_object_resource_attributes import SegmentListResponseObjectResourceAttributes
    from openapi_client.models.segment_member_response_object_resource_attributes import SegmentMemberResponseObjectResourceAttributes
    from openapi_client.models.segment_member_response_object_resource_extended import SegmentMemberResponseObjectResourceExtended
    from openapi_client.models.segment_member_response_object_resource_extended_attributes import SegmentMemberResponseObjectResourceExtendedAttributes
    from openapi_client.models.segment_partial_update_query import SegmentPartialUpdateQuery
    from openapi_client.models.segment_partial_update_query_resource_object import SegmentPartialUpdateQueryResourceObject
    from openapi_client.models.segment_partial_update_query_resource_object_attributes import SegmentPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.segment_response_object_resource import SegmentResponseObjectResource
    from openapi_client.models.segment_retrieve_response_object_resource_attributes import SegmentRetrieveResponseObjectResourceAttributes
    from openapi_client.models.segment_retrieve_response_object_resource_extended import SegmentRetrieveResponseObjectResourceExtended
    from openapi_client.models.segment_retrieve_response_object_resource_extended_attributes import SegmentRetrieveResponseObjectResourceExtendedAttributes
    from openapi_client.models.segment_series_report_enum import SegmentSeriesReportEnum
    from openapi_client.models.segment_series_request_dto import SegmentSeriesRequestDTO
    from openapi_client.models.segment_series_request_dto_resource_object import SegmentSeriesRequestDTOResourceObject
    from openapi_client.models.segment_series_request_dto_resource_object_attributes import SegmentSeriesRequestDTOResourceObjectAttributes
    from openapi_client.models.segment_values_report_enum import SegmentValuesReportEnum
    from openapi_client.models.segment_values_request_dto import SegmentValuesRequestDTO
    from openapi_client.models.segment_values_request_dto_resource_object import SegmentValuesRequestDTOResourceObject
    from openapi_client.models.segment_values_request_dto_resource_object_attributes import SegmentValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.send_options import SendOptions
    from openapi_client.models.send_strategy_sub_object import SendStrategySubObject
    from openapi_client.models.send_time_sub_object import SendTimeSubObject
    from openapi_client.models.series_data import SeriesData
    from openapi_client.models.server_bis_subscription_create_query import ServerBISSubscriptionCreateQuery
    from openapi_client.models.server_bis_subscription_create_query_resource_object import ServerBISSubscriptionCreateQueryResourceObject
    from openapi_client.models.server_bis_subscription_create_query_resource_object_attributes import ServerBISSubscriptionCreateQueryResourceObjectAttributes
    from openapi_client.models.server_bis_subscription_create_query_resource_object_attributes_profile import ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile
    from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships import ServerBISSubscriptionCreateQueryResourceObjectRelationships
    from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariant
    from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant_data import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData
    from openapi_client.models.static_schedule_options import StaticScheduleOptions
    from openapi_client.models.street_address import StreetAddress
    from openapi_client.models.subscription_channels import SubscriptionChannels
    from openapi_client.models.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
    from openapi_client.models.subscription_create_job_create_query_resource_object import SubscriptionCreateJobCreateQueryResourceObject
    from openapi_client.models.subscription_create_job_create_query_resource_object_attributes import SubscriptionCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.subscription_create_job_create_query_resource_object_attributes_profiles import SubscriptionCreateJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.subscription_create_job_create_query_resource_object_relationships import SubscriptionCreateJobCreateQueryResourceObjectRelationships
    from openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list import SubscriptionCreateJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list_data import SubscriptionCreateJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.subscription_delete_job_create_query import SubscriptionDeleteJobCreateQuery
    from openapi_client.models.subscription_delete_job_create_query_resource_object import SubscriptionDeleteJobCreateQueryResourceObject
    from openapi_client.models.subscription_delete_job_create_query_resource_object_attributes import SubscriptionDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.subscription_delete_job_create_query_resource_object_attributes_profiles import SubscriptionDeleteJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships import SubscriptionDeleteJobCreateQueryResourceObjectRelationships
    from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list_data import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.subscription_parameters import SubscriptionParameters
    from openapi_client.models.subscriptions import Subscriptions
    from openapi_client.models.suppression_create_job_create_query import SuppressionCreateJobCreateQuery
    from openapi_client.models.suppression_create_job_create_query_resource_object import SuppressionCreateJobCreateQueryResourceObject
    from openapi_client.models.suppression_create_job_create_query_resource_object_attributes import SuppressionCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.suppression_create_job_create_query_resource_object_attributes_profiles import SuppressionCreateJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships import SuppressionCreateJobCreateQueryResourceObjectRelationships
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list import SuppressionCreateJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list_data import SuppressionCreateJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment import SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegment
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment_data import SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegmentData
    from openapi_client.models.suppression_delete_job_create_query import SuppressionDeleteJobCreateQuery
    from openapi_client.models.suppression_delete_job_create_query_resource_object import SuppressionDeleteJobCreateQueryResourceObject
    from openapi_client.models.suppression_delete_job_create_query_resource_object_attributes import SuppressionDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.suppression_delete_job_create_query_resource_object_attributes_profiles import SuppressionDeleteJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships import SuppressionDeleteJobCreateQueryResourceObjectRelationships
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list_data import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegment
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment_data import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegmentData
    from openapi_client.models.tag_campaign_op import TagCampaignOp
    from openapi_client.models.tag_campaign_op_data_inner import TagCampaignOpDataInner
    from openapi_client.models.tag_create_query import TagCreateQuery
    from openapi_client.models.tag_create_query_resource_object import TagCreateQueryResourceObject
    from openapi_client.models.tag_create_query_resource_object_relationships import TagCreateQueryResourceObjectRelationships
    from openapi_client.models.tag_create_query_resource_object_relationships_tag_group import TagCreateQueryResourceObjectRelationshipsTagGroup
    from openapi_client.models.tag_create_query_resource_object_relationships_tag_group_data import TagCreateQueryResourceObjectRelationshipsTagGroupData
    from openapi_client.models.tag_enum import TagEnum
    from openapi_client.models.tag_flow_op import TagFlowOp
    from openapi_client.models.tag_flow_op_data_inner import TagFlowOpDataInner
    from openapi_client.models.tag_group_create_query import TagGroupCreateQuery
    from openapi_client.models.tag_group_create_query_resource_object import TagGroupCreateQueryResourceObject
    from openapi_client.models.tag_group_create_query_resource_object_attributes import TagGroupCreateQueryResourceObjectAttributes
    from openapi_client.models.tag_group_enum import TagGroupEnum
    from openapi_client.models.tag_group_response_object_resource import TagGroupResponseObjectResource
    from openapi_client.models.tag_group_response_object_resource_attributes import TagGroupResponseObjectResourceAttributes
    from openapi_client.models.tag_group_update_query import TagGroupUpdateQuery
    from openapi_client.models.tag_group_update_query_resource_object import TagGroupUpdateQueryResourceObject
    from openapi_client.models.tag_group_update_query_resource_object_attributes import TagGroupUpdateQueryResourceObjectAttributes
    from openapi_client.models.tag_list_op import TagListOp
    from openapi_client.models.tag_list_op_data_inner import TagListOpDataInner
    from openapi_client.models.tag_response_object_resource import TagResponseObjectResource
    from openapi_client.models.tag_response_object_resource_attributes import TagResponseObjectResourceAttributes
    from openapi_client.models.tag_segment_op import TagSegmentOp
    from openapi_client.models.tag_segment_op_data_inner import TagSegmentOpDataInner
    from openapi_client.models.tag_update_query import TagUpdateQuery
    from openapi_client.models.tag_update_query_resource_object import TagUpdateQueryResourceObject
    from openapi_client.models.template_clone_query import TemplateCloneQuery
    from openapi_client.models.template_clone_query_resource_object import TemplateCloneQueryResourceObject
    from openapi_client.models.template_clone_query_resource_object_attributes import TemplateCloneQueryResourceObjectAttributes
    from openapi_client.models.template_create_query import TemplateCreateQuery
    from openapi_client.models.template_create_query_resource_object import TemplateCreateQueryResourceObject
    from openapi_client.models.template_create_query_resource_object_attributes import TemplateCreateQueryResourceObjectAttributes
    from openapi_client.models.template_enum import TemplateEnum
    from openapi_client.models.template_render_query import TemplateRenderQuery
    from openapi_client.models.template_render_query_resource_object import TemplateRenderQueryResourceObject
    from openapi_client.models.template_render_query_resource_object_attributes import TemplateRenderQueryResourceObjectAttributes
    from openapi_client.models.template_response_object_resource import TemplateResponseObjectResource
    from openapi_client.models.template_response_object_resource_attributes import TemplateResponseObjectResourceAttributes
    from openapi_client.models.template_universal_content_enum import TemplateUniversalContentEnum
    from openapi_client.models.template_update_query import TemplateUpdateQuery
    from openapi_client.models.template_update_query_resource_object import TemplateUpdateQueryResourceObject
    from openapi_client.models.template_update_query_resource_object_attributes import TemplateUpdateQueryResourceObjectAttributes
    from openapi_client.models.throttled_schedule_options import ThrottledScheduleOptions
    from openapi_client.models.tracking_param_dto import TrackingParamDTO
    from openapi_client.models.tracking_setting_enum import TrackingSettingEnum
    from openapi_client.models.tracking_setting_partial_update_query import TrackingSettingPartialUpdateQuery
    from openapi_client.models.tracking_setting_partial_update_query_resource_object import TrackingSettingPartialUpdateQueryResourceObject
    from openapi_client.models.tracking_setting_partial_update_query_resource_object_attributes import TrackingSettingPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.tracking_setting_response_object_resource import TrackingSettingResponseObjectResource
    from openapi_client.models.tracking_setting_response_object_resource_attributes import TrackingSettingResponseObjectResourceAttributes
    from openapi_client.models.universal_content_create_query import UniversalContentCreateQuery
    from openapi_client.models.universal_content_create_query_resource_object import UniversalContentCreateQueryResourceObject
    from openapi_client.models.universal_content_create_query_resource_object_attributes import UniversalContentCreateQueryResourceObjectAttributes
    from openapi_client.models.universal_content_partial_update_query import UniversalContentPartialUpdateQuery
    from openapi_client.models.universal_content_partial_update_query_resource_object import UniversalContentPartialUpdateQueryResourceObject
    from openapi_client.models.universal_content_partial_update_query_resource_object_attributes import UniversalContentPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.universal_content_response_object_resource import UniversalContentResponseObjectResource
    from openapi_client.models.universal_content_response_object_resource_attributes import UniversalContentResponseObjectResourceAttributes
    from openapi_client.models.values_data import ValuesData
    from openapi_client.models.webhook_create_query import WebhookCreateQuery
    from openapi_client.models.webhook_create_query_resource_object import WebhookCreateQueryResourceObject
    from openapi_client.models.webhook_create_query_resource_object_attributes import WebhookCreateQueryResourceObjectAttributes
    from openapi_client.models.webhook_create_query_resource_object_relationships import WebhookCreateQueryResourceObjectRelationships
    from openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics import WebhookCreateQueryResourceObjectRelationshipsWebhookTopics
    from openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics_data_inner import WebhookCreateQueryResourceObjectRelationshipsWebhookTopicsDataInner
    from openapi_client.models.webhook_enum import WebhookEnum
    from openapi_client.models.webhook_partial_update_query import WebhookPartialUpdateQuery
    from openapi_client.models.webhook_partial_update_query_resource_object import WebhookPartialUpdateQueryResourceObject
    from openapi_client.models.webhook_partial_update_query_resource_object_attributes import WebhookPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.webhook_response_object_resource import WebhookResponseObjectResource
    from openapi_client.models.webhook_response_object_resource_attributes import WebhookResponseObjectResourceAttributes
    from openapi_client.models.webhook_topic_enum import WebhookTopicEnum
    from openapi_client.models.webhook_topic_response_object_resource import WebhookTopicResponseObjectResource



# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    The version of the OpenAPI document: 2024-10-15
    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class DeviceMetadata(BaseModel):
    """
    DeviceMetadata
    """ # noqa: E501
    device_id: Optional[StrictStr] = Field(default=None, description="Relatively stable ID for the device. Will update on app uninstall and reinstall")
    klaviyo_sdk: Optional[StrictStr] = Field(default=None, description="The name of the SDK used to create the push token.")
    sdk_version: Optional[StrictStr] = Field(default=None, description="The version of the SDK used to create the push token")
    device_model: Optional[StrictStr] = Field(default=None, description="The model of the device")
    os_name: Optional[StrictStr] = Field(default=None, description="The name of the operating system on the device.")
    os_version: Optional[StrictStr] = Field(default=None, description="The version of the operating system on the device")
    manufacturer: Optional[StrictStr] = Field(default=None, description="The manufacturer of the device")
    app_name: Optional[StrictStr] = Field(default=None, description="The name of the app that created the push token")
    app_version: Optional[StrictStr] = Field(default=None, description="The version of the app that created the push token")
    app_build: Optional[StrictStr] = Field(default=None, description="The build of the app that created the push token")
    app_id: Optional[StrictStr] = Field(default=None, description="The ID of the app that created the push token")
    environment: Optional[StrictStr] = Field(default=None, description="The environment in which the push token was created")
    __properties: ClassVar[List[str]] = ["device_id", "klaviyo_sdk", "sdk_version", "device_model", "os_name", "os_version", "manufacturer", "app_name", "app_version", "app_build", "app_id", "environment"]

    @field_validator('klaviyo_sdk')
    def klaviyo_sdk_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['android', 'flutter_community', 'react_native', 'swift']):
            raise ValueError("must be one of enum values ('android', 'flutter_community', 'react_native', 'swift')")
        return value

    @field_validator('os_name')
    def os_name_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['android', 'ios', 'ipados', 'macos', 'tvos']):
            raise ValueError("must be one of enum values ('android', 'ios', 'ipados', 'macos', 'tvos')")
        return value

    @field_validator('environment')
    def environment_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['debug', 'release']):
            raise ValueError("must be one of enum values ('debug', 'release')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DeviceMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if device_id (nullable) is None
        # and model_fields_set contains the field
        if self.device_id is None and "device_id" in self.model_fields_set:
            _dict['device_id'] = None

        # set to None if klaviyo_sdk (nullable) is None
        # and model_fields_set contains the field
        if self.klaviyo_sdk is None and "klaviyo_sdk" in self.model_fields_set:
            _dict['klaviyo_sdk'] = None

        # set to None if sdk_version (nullable) is None
        # and model_fields_set contains the field
        if self.sdk_version is None and "sdk_version" in self.model_fields_set:
            _dict['sdk_version'] = None

        # set to None if device_model (nullable) is None
        # and model_fields_set contains the field
        if self.device_model is None and "device_model" in self.model_fields_set:
            _dict['device_model'] = None

        # set to None if os_name (nullable) is None
        # and model_fields_set contains the field
        if self.os_name is None and "os_name" in self.model_fields_set:
            _dict['os_name'] = None

        # set to None if os_version (nullable) is None
        # and model_fields_set contains the field
        if self.os_version is None and "os_version" in self.model_fields_set:
            _dict['os_version'] = None

        # set to None if manufacturer (nullable) is None
        # and model_fields_set contains the field
        if self.manufacturer is None and "manufacturer" in self.model_fields_set:
            _dict['manufacturer'] = None

        # set to None if app_name (nullable) is None
        # and model_fields_set contains the field
        if self.app_name is None and "app_name" in self.model_fields_set:
            _dict['app_name'] = None

        # set to None if app_version (nullable) is None
        # and model_fields_set contains the field
        if self.app_version is None and "app_version" in self.model_fields_set:
            _dict['app_version'] = None

        # set to None if app_build (nullable) is None
        # and model_fields_set contains the field
        if self.app_build is None and "app_build" in self.model_fields_set:
            _dict['app_build'] = None

        # set to None if app_id (nullable) is None
        # and model_fields_set contains the field
        if self.app_id is None and "app_id" in self.model_fields_set:
            _dict['app_id'] = None

        # set to None if environment (nullable) is None
        # and model_fields_set contains the field
        if self.environment is None and "environment" in self.model_fields_set:
            _dict['environment'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DeviceMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "device_id": obj.get("device_id"),
            "klaviyo_sdk": obj.get("klaviyo_sdk"),
            "sdk_version": obj.get("sdk_version"),
            "device_model": obj.get("device_model"),
            "os_name": obj.get("os_name"),
            "os_version": obj.get("os_version"),
            "manufacturer": obj.get("manufacturer"),
            "app_name": obj.get("app_name"),
            "app_version": obj.get("app_version"),
            "app_build": obj.get("app_build"),
            "app_id": obj.get("app_id"),
            "environment": obj.get("environment")
        })
        return _obj





# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    The version of the OpenAPI document: 2024-10-15
    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from openapi_client.models.catalog_variant_enum import CatalogVariantEnum
from typing import Optional, Set
from typing_extensions import Self

class ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData(BaseModel):
    """
    ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData
    """ # noqa: E501
    type: CatalogVariantEnum
    id: StrictStr = Field(description="The catalog variant ID for which the profile is subscribing to back in stock notifications. This ID is made up of the integration type, catalog ID, and and the external ID of the variant like so: `integrationType:::catalogId:::externalId`. If the integration you are using is not set up for multi-catalog storage, the 'catalogId' will be `$default`. For Shopify `$shopify:::$default:::33001893429341`")
    __properties: ClassVar[List[str]] = ["type", "id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "id": obj.get("id")
        })
        return _obj





# flake8: noqa

from openapi_client import lazy_imports

# import apis into api package
if not lazy_imports:
    from openapi_client.api.accounts_api import AccountsApi
    from openapi_client.api.campaigns_api import CampaignsApi
    from openapi_client.api.catalogs_api import CatalogsApi
    from openapi_client.api.coupons_api import CouponsApi
    from openapi_client.api.data_privacy_api import DataPrivacyApi
    from openapi_client.api.events_api import EventsApi
    from openapi_client.api.flows_api import FlowsApi
    from openapi_client.api.forms_api import FormsApi
    from openapi_client.api.images_api import ImagesApi
    from openapi_client.api.lists_api import ListsApi
    from openapi_client.api.metrics_api import MetricsApi
    from openapi_client.api.profiles_api import ProfilesApi
    from openapi_client.api.reporting_api import ReportingApi
    from openapi_client.api.reviews_api import ReviewsApi
    from openapi_client.api.segments_api import SegmentsApi
    from openapi_client.api.tags_api import TagsApi
    from openapi_client.api.templates_api import TemplatesApi
    from openapi_client.api.tracking_settings_api import TrackingSettingsApi
    from openapi_client.api.webhooks_api import WebhooksApi
    